==> trilinos_9.0.3.dfsg.orig.tar.gz: trilinos-9.0.3.dfsg.orig/packages/sacado/src/Sacado_CacheFad_GeneralFadExpr.hpp <==
// $Id: Sacado_CacheFad_GeneralFadExpr.hpp,v 1.3 2007/02/22 22:09:33 dmgay Exp $ 
// $Source: /space/CVS/Trilinos/packages/sacado/src/Sacado_CacheFad_GeneralFadExpr.hpp,v $ 
// @HEADER
// ***********************************************************************
// 
//                           Sacado Package
//                 Copyright (2006) Sandia Corporation
// 
// Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
// the U.S. Government retains certain rights in this software.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact David M. Gay (dmgay@sandia.gov) or Eric T. Phipps
// (etphipp@sandia.gov).
// 
// ***********************************************************************
// @HEADER

#ifndef SACADO_CACHEFAD_GENERALFADEXPR_HPP
#define SACADO_CACHEFAD_GENERALFADEXPR_HPP

#include "Sacado_CacheFad_GeneralFad.hpp"

namespace Sacado {

  namespace CacheFad {

    //! GeneralFad expression template specialization
    /*!
     * This template class represents a simple GeneralFad expression and
     * mixes-in the GeneralFad interface and the expression template
     * interface using the caching expression templates.
     */
    template <typename T, typename Storage> 
    class Expr< GeneralFad<T,Storage> > : public GeneralFad<T,Storage> {

    public:

      //! Default constructor
      Expr() : 
	GeneralFad<T,Storage>() {}

      //! Constructor with supplied value \c x
      /*!
       * Initializes value to \c x and derivative array is empty
       */
      Expr(const T & x) : 
	GeneralFad<T,Storage>(x) {}

      //! Constructor with size \c sz and value \c x
      /*!
       * Initializes value to \c x and derivative array 0 of length \c sz
       */
      Expr(const int sz, const T & x) : 
	GeneralFad<T,Storage>(sz,x) {}

      //! Constructor with size \c sz, index \c i, and value \c x
      /*!
       * Initializes value to \c x and derivative array of length \c sz
       * as row \c i of the identity matrix, i.e., sets derivative component
       * \c i to 1 and all other's to zero.
       */
      Expr(const int sz, const int i, const T & x) : 
	GeneralFad<T,Storage>(sz,i,x) {}

      //! Copy constructor
      Expr(const Expr& x) : 
	GeneralFad<T,Storage>(x) {}

      //! Copy constructor from any Expression object
      template <typename S> Expr(const Expr<S>& x) :
	GeneralFad<T,Storage>(x) {}

      //! Destructor
      ~Expr() {}

    }; // class Expr<GeneralFad>

  } // namespace CacheFad

} // namespace Sacado

#include "Sacado_CacheFad_Ops.hpp"

#endif // SACADO_CACHEFAD_GENERALFADEXPR_HPP

==> trilinos_10.0.4.dfsg.orig.tar.gz: trilinos-10.0.4.dfsg.orig/packages/sacado/src/Sacado_CacheFad_GeneralFadExpr.hpp <==
// $Id$ 
// $Source$ 
// @HEADER
// ***********************************************************************
// 
//                           Sacado Package
//                 Copyright (2006) Sandia Corporation
// 
// Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
// the U.S. Government retains certain rights in this software.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact David M. Gay (dmgay@sandia.gov) or Eric T. Phipps
// (etphipp@sandia.gov).
// 
// ***********************************************************************
// @HEADER

#ifndef SACADO_CACHEFAD_GENERALFADEXPR_HPP
#define SACADO_CACHEFAD_GENERALFADEXPR_HPP

#include "Sacado_CacheFad_GeneralFad.hpp"

namespace Sacado {

  namespace CacheFad {

    //! GeneralFad expression template specialization
    /*!
     * This template class represents a simple GeneralFad expression and
     * mixes-in the GeneralFad interface and the expression template
     * interface using the caching expression templates.
     */
    template <typename T, typename Storage> 
    class Expr< GeneralFad<T,Storage> > : public GeneralFad<T,Storage> {

    public:

      typedef typename GeneralFad<T,Storage>::value_type value_type;
      typedef typename GeneralFad<T,Storage>::scalar_type scalar_type;

      //! Default constructor
      Expr() : 
	GeneralFad<T,Storage>() {}

      //! Constructor with supplied value \c x
      /*!
       * Initializes value to \c x and derivative array is empty
       */
      Expr(const T & x) : 
	GeneralFad<T,Storage>(x) {}

      //! Constructor with size \c sz and value \c x
      /*!
       * Initializes value to \c x and derivative array 0 of length \c sz
       */
      Expr(const int sz, const T & x) : 
	GeneralFad<T,Storage>(sz,x) {}

      //! Constructor with size \c sz, index \c i, and value \c x
      /*!
       * Initializes value to \c x and derivative array of length \c sz
       * as row \c i of the identity matrix, i.e., sets derivative component
       * \c i to 1 and all other's to zero.
       */
      Expr(const int sz, const int i, const T & x) : 
	GeneralFad<T,Storage>(sz,i,x) {}

      //! Copy constructor
      Expr(const Expr& x) : 
	GeneralFad<T,Storage>(x) {}

      //! Copy constructor from any Expression object
      template <typename S> Expr(const Expr<S>& x) :
	GeneralFad<T,Storage>(x) {}

      //! Destructor
      ~Expr() {}

    }; // class Expr<GeneralFad>

  } // namespace CacheFad

} // namespace Sacado

#include "Sacado_CacheFad_Ops.hpp"

#endif // SACADO_CACHEFAD_GENERALFADEXPR_HPP
